module.exports = [
  // This is an example redirect, it can be removed once other redirects have been added
  {
    source: '/home',
    destination: '/',
    permanent: true,
  },
]
